==> pyaliyun-1.0.2.tar.gz: pyaliyun-1.0.2/pyaliyun/mns/api.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

"""
参考: https://help.aliyun.com/product/27412.html?spm=5176.doc35134.3.1.vkdmiJ
"""
import base64

from ..core.api import BaseApi
from ..core.request import AliRequest
from ..core.utils import dict_to_xml


class MnsQueueApi(BaseApi):
    """
    消息服务 队列api
    """

    def __init__(self, host, account, schema="https", service="MNS"):
        """
        :param account:
        :param endpoint: http(s)://1698467070378510.mns.cn-hangzhou.aliyuncs.com/
        :param service:
        """
        self._version = "2015-06-06"
        self._content_type = "XML"
        self._xmlns = "http://mns.aliyuncs.com/doc/v1/"
        self._host = host
        self._schema = schema
        self._endpoint = "%s://%s" % (self._schema, self._host)
        self._header_prefix = "x-mns-"
        super(MnsQueueApi, self).__init__(account, service)

    def process_post_body(self, data, data_tag_name):
        if self._content_type == "XML":
            return dict_to_xml(data_tag_name, data, self._xmlns)
        else:
            return str(data)

    def get_request(self, resource):
        request = AliRequest(
            host=self._host,
            ak_id=self._account.access_key,
            ak_secret=self._account.access_secret,
            resource=resource,
            aliyun_service=self._service,
            header_prefix=self._header_prefix,
            method="POST",
            scheme="https"
        )
        request.add_headers({"x-mns-version": self._version})
        return request

    def send_message(self, queue_name, message_body, delay=0, priority=8):
        """
        https://help.aliyun.com/document_detail/35134.html?spm=5176.doc32295.6.686.ZZ6M35
        发送消息
        :return:
        """
        resource = '/queues/%s/messages' % queue_name
        origin_data = {
            "MessageBody": base64.b64encode(message_body),
            "DelaySeconds": str(delay),
            "Priority": str(priority)
        }
        post_data = self.process_post_body(origin_data, "Message")
        req = self.get_request(resource)
        resp = req.post(post_data)
        return resp

    def __str__(self):
        return "MNS API SERVICE"

==> pyaliyun-1.0.4.1.tar.gz: pyaliyun-1.0.4.1/pyaliyun/mns/api.py <==
#!/usr/bin/python
# -*- coding: utf-8 -*-

"""
参考: https://help.aliyun.com/product/27412.html?spm=5176.doc35134.3.1.vkdmiJ
"""
import base64

from pyaliyun.core.api import BaseApi
from pyaliyun.core.encoding import force_bytes
from pyaliyun.core.request import AliRequest
from pyaliyun.core.utils import dict_to_xml


class MnsQueueApi(BaseApi):
    """
    消息服务 队列api
    """

    def __init__(self, host, account, schema="https", service="MNS"):
        """
        :param account:
        :param endpoint: http(s)://1698467070378510.mns.cn-hangzhou.aliyuncs.com/
        :param service:
        """
        self._version = "2015-06-06"
        self._content_type = "XML"
        self._xmlns = "http://mns.aliyuncs.com/doc/v1/"
        self._host = host
        self._schema = schema
        self._endpoint = "%s://%s" % (self._schema, self._host)
        self._header_prefix = "x-mns-"
        super(MnsQueueApi, self).__init__(account, service)

    def process_post_body(self, data, data_tag_name):
        if self._content_type == "XML":
            return dict_to_xml(data_tag_name, data, self._xmlns)
        else:
            return str(data)

    def get_request(self, resource):
        request = AliRequest(
            host=self._host,
            ak_id=self._account.access_key,
            ak_secret=self._account.access_secret,
            resource=resource,
            aliyun_service=self._service,
            header_prefix=self._header_prefix,
            method="POST",
            scheme="https"
        )
        request.add_headers({"x-mns-version": self._version})
        return request

    def send_message(self, queue_name, message_body, delay=0, priority=8):
        """
        https://help.aliyun.com/document_detail/35134.html?spm=5176.doc32295.6.686.ZZ6M35
        发送消息
        :return:
        """
        resource = '/queues/%s/messages' % queue_name
        origin_data = {
            "MessageBody": base64.b64encode(force_bytes(message_body)),
            "DelaySeconds": str(delay),
            "Priority": str(priority)
        }
        post_data = self.process_post_body(origin_data, "Message")
        req = self.get_request(resource)
        resp = req.post(post_data)
        return resp

    def __str__(self):
        return "MNS API SERVICE"
